% This code computes the Local Frame Match Distance (LFMD) matrix given
% a cell array of temporal paths (hand gestures).
%
% Copyright (C) 2017  Radu Tudor Ionescu, Marius Popescu,
%                     Christopher Conly, Vassilis Athitsos
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or any
% later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%

clear java;
javaaddpath('.');

load('temporalPaths.mat','features');

numSamples = numel(features);

D = zeros(numSamples, numSamples);
for i = 1:numSamples

    fprintf('Computing distance between path %d versus rest...\n', i);
    
    for j = i:numSamples
    
        % LFMD based on 1-frames:
        % D(i,j) = DistanceAlgorithms.LFMD(features{i}, features{j}, 10);
        
        % LFMD based on 2-frames:
        % D(i,j) = DistanceAlgorithms.LFMD2(features{i}, features{j}, 10);

        % LFMD based on 3-frames:
        % D(i,j) = DistanceAlgorithms.LFMD3(features{i}, features{j}, 10);

        % LFMD based on 4-frames:
        % D(i,j) = DistanceAlgorithms.LFMD4(features{i}, features{j}, 10);

        % LFMD based on 1-frames + 2-frames:
        D(i,j) = DistanceAlgorithms.LFMD(features{i}, features{j}, 10) + ...
                 DistanceAlgorithms.LFMD2(features{i}, features{j}, 10);
        
        D(j,i) = D(i,j);
    end
    
end

D
save(sprintf('LFMD-frames1+2.mat'), 'D', '-v7.3');
